@@ -1,5 +1,4 @@
-# $File: //member/autrijus/PAR/myldr/parlsig.pl $ $Author: autrijus $
-# $Revision: #2 $ $Change: 7306 $ $DateTime: 2003/08/02 12:53:31 $
+use strict;
 
 my ($parl_exe, $par_exe, $dynperl, $chunk_size) = @ARGV;
 exit unless $dynperl;
